## misc

1. crawl

Google news crawler. To use it, as simple as,

```bash
python3 main.py -i "isu mahathir" -s 2009 -e 2019 -l 10
```

Read more at [crawl](crawl).

2. deployment

Comparison between common python web frameworks using wrk,

Read full report at [deployment](deployment).

3. translator

Multithread google translate without get block. Translation is common technique to build weak models.

Read more at [translator](translator).